==> frezka_customer_app_v2.1.0_update_code.zip: lib/utils/images.dart <==
const app_logo = "assets/app_logo.png";
const walk_img1 = 'assets/images/walk_img_1.png';
const walk_img2 = 'assets/images/walk_img_2.png';
const walk_img3 = 'assets/images/walk_img_3.png';
const bg_pattern = 'assets/images/bg_pattern.png';
const Slider_img2 = 'assets/images/img_slider2.png';
const razorpay_logo = 'assets/images/razorpay_logo.png';
const stripe_logo = 'assets/images/stripe_logo.png';
const paypal_logo = 'assets/images/paypal_logo.png';
const paystack_logo = 'assets/images/paystack_logo.png';
const flutter_wave_logo = 'assets/images/flutter_wave_logo.png';
const paytm_logo = 'assets/images/paytm_logo.png';
const logo_gif = 'assets/images/logo_gif.gif';
const imgForceUpdate = 'assets/images/force_update.png';
const product_1 = 'assets/images/product_1.png';
const product_2 = 'assets/images/product_2.png';
const product_3 = 'assets/images/product_3.png';
const product_4 = 'assets/images/product_4.png';
const product_5 = 'assets/images/product_5.png';
const product_6 = 'assets/images/product_6.png';
const product = 'assets/images/product.jpg';
const product_img_1 = 'assets/images/product_img_1.png';
const product_img_2 = 'assets/images/product_img_2.jpg';
const brand_1 = 'assets/images/brand_1.png';
const brand_2 = 'assets/images/brand_2.png';
const brand_3 = 'assets/images/brand_3.png';
const brand_4 = 'assets/images/brand_4.png';
const brand_5 = 'assets/images/brand_5.png';
const brand_6 = 'assets/images/brand_6.png';
const brand_7 = 'assets/images/brand_7.png';
const brand_8 = 'assets/images/brand_8.png';

const ic_us = 'assets/flags/ic_us.png';
const ic_india = 'assets/flags/ic_india.png';
const ic_ar = 'assets/flags/ic_ar.png';
const ic_fr = 'assets/flags/ic_fr.png';
const ic_de = 'assets/flags/ic_de.png';
const ic_no_photo = "assets/icons/ic_no_photo.png";
const ic_confetti_ball = "assets/icons/ic_confetti_ball.png";
const ic_selected_bell = "assets/icons/ic_selected_bell.png";
const ic_selected_booking = "assets/icons/ic_selected_booking.png";
const ic_selected_home = "assets/icons/ic_selected_home.png";
const ic_selected_profile = "assets/icons/ic_selected_profile.png";
const ic_unselected_bell = "assets/icons/ic_unselected_bell.png";
const ic_unselected_home = "assets/icons/ic_unselected_home.png";
const ic_unselected_profile = "assets/icons/ic_unselected_profile.png";
const ic_app_language = "assets/icons/ic_app_language.png";
const ic_dark_mode = "assets/icons/ic_dark_mode.png";
const ic_help = "assets/icons/ic_help.png";
const ic_logout = "assets/icons/ic_logout.png";
const ic_setting = "assets/icons/ic_setting.png";
const ic_hi = "assets/icons/ic_hi.png";
const ic_location = "assets/icons/ic_location.png";
const ic_direction = "assets/icons/ic_direction.png";
const ic_star = "assets/icons/ic_star.png";
const ic_call = 'assets/icons/ic_call.png';
const ic_share = 'assets/icons/ic_share.png';
const ic_unselected_booking = 'assets/icons/ic_unselected_booking.png';
const ic_facebook = 'assets/icons/ic_facebook.png';
const ic_instagram = 'assets/icons/ic_instagram.png';
const ic_dribble = 'assets/icons/ic_dribble.png';
const ic_twitter = 'assets/icons/ic_twitter.png';
const ic_business = 'assets/icons/ic_business.png';
const ic_confirm_check = 'assets/icons/ic_confirm_check.png';
const ic_clock = 'assets/icons/ic_clock.png';
const ic_message = 'assets/icons/ic_message.png';
const ic_about = 'assets/icons/ic_about.png';
const ic_terms_conditions = 'assets/icons/ic_terms_conditions.png';
const ic_privacy_policy = 'assets/icons/ic_privacy_policy.png';
const ic_arrow_right = 'assets/icons/ic_arrow_right.png';
const ic_hide = 'assets/icons/ic_hide.png';
const ic_show = 'assets/icons/ic_show.png';
const ic_lock = 'assets/icons/ic_lock.png';
const ic_notification_user = 'assets/icons/ic_notification_user.png';
const ic_edit_square = 'assets/icons/ic_edit_square.png';
const ic_delete = 'assets/icons/ic_delete.png';
const ic_delete_account = 'assets/icons/ic_delete_account.png';
const ic_payment = 'assets/icons/ic_payment.png';
const ic_fill_heart = 'assets/icons/ic_fill_heart.png';
const ic_heart = 'assets/icons/ic_heart.png';
const ic_selected_shop = 'assets/icons/ic_selected_shop.png';
const ic_unselected_shop = 'assets/icons/ic_unselected_shop.png';
const ic_filter = 'assets/icons/ic_filter.png';
const ic_navigate = 'assets/icons/ic_navigate.png';
const ic_verified = 'assets/icons/ic_verified.png';
const ic_add = 'assets/icons/ic_add.png';
const ic_minus = 'assets/icons/ic_minus.png';
const ic_dislike = 'assets/icons/ic_dislike.png';
const ic_fill_dislike = 'assets/icons/ic_fill_dislike.png';
const ic_fill_like = 'assets/icons/ic_fill_like.png';
const ic_like = 'assets/icons/ic_like.png';
const ic_order = 'assets/icons/ic_order.png';
const ic_booking_status = 'assets/icons/ic_booking_status.png';

==> frezka_customer_app_v3.1.0_update_code.zip: lib/utils/images.dart <==
const app_logo = "assets/app_logo.png";
const walk_img1 = 'assets/images/walk_img_1.png';
const walk_img2 = 'assets/images/walk_img_2.png';
const walk_img3 = 'assets/images/walk_img_3.png';
const bg_pattern = 'assets/images/bg_pattern.png';
const Slider_img2 = 'assets/images/img_slider2.png';
const razorpay_logo = 'assets/images/razorpay_logo.png';
const stripe_logo = 'assets/images/stripe_logo.png';
const paypal_logo = 'assets/images/paypal_logo.png';
const ic_airtel_money_logo = 'assets/images/ic_airtel_money_logo.png';
const paystack_logo = 'assets/images/paystack_logo.png';
const flutter_wave_logo = 'assets/images/flutter_wave_logo.png';
const ic_cinet_pay = 'assets/images/ic_cinet_pay.png';
const ic_sadad_payment = 'assets/images/ic_sadad_payment.png';
const ic_midtrance_pay = 'assets/images/ic_midtrance_pay.jpg';
const ic_phone_pe = 'assets/images/ic_phone_pe.png';

const paytm_logo = 'assets/images/paytm_logo.png';
const logo_gif = 'assets/images/logo_gif.gif';
const imgForceUpdate = 'assets/images/force_update.png';
const product_1 = 'assets/images/product_1.png';
const product_2 = 'assets/images/product_2.png';
const product_3 = 'assets/images/product_3.png';
const product_4 = 'assets/images/product_4.png';
const product_5 = 'assets/images/product_5.png';
const product_6 = 'assets/images/product_6.png';
const product = 'assets/images/product.jpg';
const product_img_1 = 'assets/images/product_img_1.png';
const product_img_2 = 'assets/images/product_img_2.jpg';
const brand_1 = 'assets/images/brand_1.png';
const brand_2 = 'assets/images/brand_2.png';
const brand_3 = 'assets/images/brand_3.png';
const brand_4 = 'assets/images/brand_4.png';
const brand_5 = 'assets/images/brand_5.png';
const brand_6 = 'assets/images/brand_6.png';
const brand_7 = 'assets/images/brand_7.png';
const brand_8 = 'assets/images/brand_8.png';

const ic_us = 'assets/flags/ic_us.png';
const ic_india = 'assets/flags/ic_india.png';
const ic_ar = 'assets/flags/ic_ar.png';
const ic_fr = 'assets/flags/ic_fr.png';
const ic_de = 'assets/flags/ic_de.png';
const ic_es = 'assets/flags/ic_es.png';
const ic_no_photo = "assets/icons/ic_no_photo.png";
const ic_confetti_ball = "assets/icons/ic_confetti_ball.png";
const ic_selected_bell = "assets/icons/ic_selected_bell.png";
const ic_selected_booking = "assets/icons/ic_selected_booking.png";
const ic_selected_home = "assets/icons/ic_selected_home.png";
const ic_selected_profile = "assets/icons/ic_selected_profile.png";
const ic_unselected_bell = "assets/icons/ic_unselected_bell.png";
const ic_unselected_home = "assets/icons/ic_unselected_home.png";
const ic_unselected_profile = "assets/icons/ic_unselected_profile.png";
const ic_app_language = "assets/icons/ic_app_language.png";
const ic_dark_mode = "assets/icons/ic_dark_mode.png";
const ic_help = "assets/icons/ic_help.png";
const ic_logout = "assets/icons/ic_logout.png";
const ic_setting = "assets/icons/ic_setting.png";
const ic_hi = "assets/icons/ic_hi.png";
const ic_location = "assets/icons/ic_location.png";
const ic_gift = "assets/icons/ic_gift.png";
const ic_gift_coupon = "assets/icons/ic_gift_coupon.png";
const ic_close = "assets/icons/ic_close.png";
const ic_direction = "assets/icons/ic_direction.png";
const ic_star = "assets/icons/ic_star.png";
const ic_call = 'assets/icons/ic_call.png';
const ic_share = 'assets/icons/ic_share.png';
const ic_unselected_booking = 'assets/icons/ic_unselected_booking.png';
const ic_facebook = 'assets/icons/ic_facebook.png';
const ic_instagram = 'assets/icons/ic_instagram.png';
const ic_dribble = 'assets/icons/ic_dribble.png';
const ic_twitter = 'assets/icons/ic_twitter.png';
const ic_business = 'assets/icons/ic_business.png';
const ic_confirm_check = 'assets/icons/ic_confirm_check.png';
const ic_clock = 'assets/icons/ic_clock.png';
const ic_message = 'assets/icons/ic_message.png';
const ic_about = 'assets/icons/ic_about.png';
const ic_terms_conditions = 'assets/icons/ic_terms_conditions.png';
const ic_privacy_policy = 'assets/icons/ic_privacy_policy.png';
const ic_arrow_right = 'assets/icons/ic_arrow_right.png';
const ic_hide = 'assets/icons/ic_hide.png';
const ic_show = 'assets/icons/ic_show.png';
const ic_lock = 'assets/icons/ic_lock.png';
const ic_notification_user = 'assets/icons/ic_notification_user.png';
const ic_edit_square = 'assets/icons/ic_edit_square.png';
const ic_delete = 'assets/icons/ic_delete.png';
const ic_delete_account = 'assets/icons/ic_delete_account.png';
const ic_payment = 'assets/icons/ic_payment.png';
const ic_fill_heart = 'assets/icons/ic_fill_heart.png';
const ic_heart = 'assets/icons/ic_heart.png';
const ic_selected_shop = 'assets/icons/ic_selected_shop.png';
const ic_unselected_shop = 'assets/icons/ic_unselected_shop.png';
const ic_filter = 'assets/icons/ic_filter.png';
const ic_navigate = 'assets/icons/ic_navigate.png';
const ic_verified = 'assets/icons/ic_verified.png';
const ic_add = 'assets/icons/ic_add.png';
const ic_minus = 'assets/icons/ic_minus.png';
const ic_dislike = 'assets/icons/ic_dislike.png';
const ic_fill_dislike = 'assets/icons/ic_fill_dislike.png';
const ic_fill_like = 'assets/icons/ic_fill_like.png';
const ic_like = 'assets/icons/ic_like.png';
const ic_order = 'assets/icons/ic_order.png';
const ic_selected_order = 'assets/icons/ic_selected_order.png';
const ic_booking_status = 'assets/icons/ic_booking_status.png';
